#
# spec file for package lash
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           lash
BuildRequires:  alsa-devel e2fsprogs-devel glibc-devel gtk2-devel libjack-devel libuuid-devel libxml2-devel python-devel readline-devel swig
Summary:        Linux Audio Session Handler
Version:        0.5.4
Release:        7.pm.241.1
Group:          Productivity/Multimedia/Sound/Utilities
AutoReqProv:    on
PreReq:         %install_info_prereq
License:        GPLv2+
Url:            http://git.savannah.gnu.org/cgit/lash.git
Source:         %name-%version.tar.bz2
Source1:        %name.desktop
Source2:        %name.png
Patch0:         lash-gcc44.patch
Patch1:         lash-implicit-fortify-decl.patch
Patch2:         lash-info-entry.diff
Patch3:         lash-swig-2x.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%py_requires

%description
LASH (formerly LADCCA) is a session management system for JACK and ALSA
audio applications on GNU/Linux. Its aim is to allow you to have many
different audio programs running at once and to save the setup, close
them down, then reload the setup at some other time.

Authors:
--------
    Bob Ham <node@users.sourceforge.net>
    Dave Robillard <drobilla@connect.carelton.ca>

%prep
%setup -q

%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3

%build
./autogen.sh
%configure --enable-static=no --datadir=/usr/share/%{name}-%{version}

%install
make install DESTDIR=$RPM_BUILD_ROOT
%__rm -f %{buildroot}%{python_sitelib}/_lash.la
%__rm -f %{buildroot}%{python_sitelib}/_lash.a
%__chmod 644 %{buildroot}/%{python_sitelib}/lash.py
%__rm %{buildroot}%{_libdir}/lib*.la

# links for so.2 have to be made for older packages that link against liblash
pushd %{buildroot}%{_libdir}
        ln -s liblash.so.1 liblash.so.2
        ln -s liblash.so.1 liblash.so.2.0.0
popd

%clean
rm -rf $RPM_BUILD_ROOT

%package -n liblash1
License:        GPLv2+
Summary:        Development package for LASH
Group:          Development/Libraries/C and C++

%description -n liblash1
This package contains the library for the LASH system.

%package -n python-lash
License:        GPLv2+
Summary:        Python bindings for LASH
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Requires:       python >= %{py_ver}

%description -n python-lash
This package contains the language bindings for Python.

Authors:
--------
    Bob Ham <node@users.sourceforge.net>
    Dave Robillard <drobilla@connect.carelton.ca>

%package -n lash-devel
License:        GPLv2+
Summary:        Development package for LASH
Group:          Development/Libraries/C and C++
Requires:       libuuid-devel glibc-devel readline-devel
Requires:       liblash1 = %{version}

%description -n lash-devel
This package contains the development files for the LASH system.

Authors:
--------
    Bob Ham <node@users.sourceforge.net>
    Dave Robillard <drobilla@connect.carelton.ca>


%files
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS README TODO
%{_bindir}/*
%{_datadir}/%{name}-%{version}/

%files -n liblash1
%defattr(-,root,root)
%{_libdir}/liblash.so.*

%files -n lash-devel
%defattr(-,root,root)
%{_includedir}/*
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*.pc

%files -n python-lash
%defattr(-,root,root)
%doc pylash/test.py
%{python_sitelib}/_lash.so
%{python_sitelib}/lash.py

%post -n liblash1 -p /sbin/ldconfig

%postun -n liblash1 -p /sbin/ldconfig

%changelog
* Thu May 26 2011 idonmez@novell.com
- Add lash-swig-2x.patch: support swig 2.x
* Sun May  1 2011 toddrme2178@gmail.com
- Added 32bit compatibility libraries
- Removed test for obsolete openSUSE versions
* Sun Sep 12 2010 stephan.barth@novell.com
- update to version 0.5.4 which contains a lot of changes
- reworked the spec file to remove all warnings
- added version specific datadir tags
- added python package
- needed to create links for liblash.so.2 for downward compatibility
- removed obsolete lash-nogtk1.diff which was there for GTK1
- removed now obsolete lash-automake-fix.diff
* Mon Jun 29 2009 tiwai@suse.de
- fix buildrequires to use libjack-devel
- fix URL
* Mon Mar 23 2009 crrodriguez@suse.de
- remove static libraries and "la" files
- fix -devel package dependencies and pkgconfig files
* Fri Sep 14 2007 aj@suse.de
- Cleanup rpmlint warnings.
- Remove whitespace to build package again.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Oct 17 2005 tiwai@suse.de
- renamed to lash
- updated to version 0.5.0.
* Wed Sep 22 2004 mskibbe@suse.de
- change specfile(suse_update_desktopfile)
* Tue Apr 27 2004 ro@suse.de
- added -fno-strict-aliasing
* Mon Feb 16 2004 tiwai@suse.de
- build as non-root.
* Thu Nov 20 2003 tiwai@suse.de
- updated to 0.4.0.
- added libxml2 and devel to neededforbuild.
* Tue Sep 16 2003 tiwai@suse.de
- added desktop icon.
* Fri Aug 29 2003 tiwai@suse.de
- added the texinto entry (bug #29588).
* Thu Aug 28 2003 tiwai@suse.de
- fixed the missing inclusion of limits.h.
* Sat Aug 16 2003 adrian@suse.de
- add desktop file
* Thu Jul  3 2003 tiwai@suse.de
- initial version: 0.3.1.
